AppInfo class

AppInfo is class that stores the information of a particular app (i.e. the app that invokes methods of this class), including: name, version, canonical name, package name, build number.

Constructors

AppInfo()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

buildNumber → Future<String>
Get the build number
no setter
canonicalName → Future<String>
Get the canonical name of the app, see _genCanonicalName()
no setter
name → Future<String>
Get the app name from pubspec.yml
no setter
packageName → Future<String>
Get the name of the package that provides the app
no setter
version → Future<String>
Get the version
no setter