DcTermsPredicate enum

Dublin Core Terms predicates from http://purl.org/dc/terms/

Inheritance
Mixed-in types
Available extensions

Values

title → const DcTermsPredicate

terms:title - A name given to the resource

const DcTermsPredicate('${terms}title')
description → const DcTermsPredicate

terms:description - An account of the resource

const DcTermsPredicate('${terms}description')
creator → const DcTermsPredicate

terms:creator - An entity responsible for making the resource

const DcTermsPredicate('${terms}creator')
created → const DcTermsPredicate

terms:created - Date of creation

const DcTermsPredicate('${terms}created')
modified → const DcTermsPredicate

terms:modified - Date of last modification

const DcTermsPredicate('${terms}modified')
subject → const DcTermsPredicate

terms:subject - The topic of the resource

const DcTermsPredicate('${terms}subject')
type → const DcTermsPredicate

terms:type - The nature or genre of the resource

const DcTermsPredicate('${terms}type')
format → const DcTermsPredicate

terms:format - The file format

const DcTermsPredicate('${terms}format')
identifier → const DcTermsPredicate

terms:identifier - An unambiguous reference to the resource

const DcTermsPredicate('${terms}identifier')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uriRef → URIRef
Return the URIRef of predicate.
no setterinherited
value → String
The string value of the predicate URI.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<DcTermsPredicate>
A constant List of the values in this enum, in order of their declaration.