LogRecord class

Data model for log record data in each log entry in the permission log in a Pod

Constructors

LogRecord({required String dateTimeStr, required String resourceUrl, required String ownerWebId, required String permissionType, required String granterWebId, required String recipientWebId, required String permissionList, String? constraints})
const

Properties

constraints String?
final
dateTime String
no setter
dateTimeStr String
final
granterName String
no setter
granterWebId String
final
hashCode int
The hash code for this object.
no setterinherited
ownerName String
no setter
ownerWebId String
final
permissionList String
final
permissionType String
final
permissionTypeLabel String
no setter
recipientName String
no setter
recipientWebId String
final
resourceUrl String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolTip String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited