RdfPredicate enum

Common RDF predicates from http://www.w3.org/1999/02/22-rdf-syntax-ns#

Inheritance
Mixed-in types
Available extensions

Values

type → const RdfPredicate

rdf:type - Used to state that a resource is an instance of a class.

const RdfPredicate('${rdf}type')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uriRef → URIRef
Return the URIRef of predicate.
no setterinherited
value String
The string value of the predicate URI.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RdfPredicate>
A constant List of the values in this enum, in order of their declaration.