ResourceContentType enum

Types of the content of resources

Inheritance
Available extensions

Values

auto → const ResourceContentType

Detect the MIME type automatically at runtime

const ResourceContentType('')
turtleText → const ResourceContentType

TTL text file

const ResourceContentType('text/turtle')
plainText → const ResourceContentType

Plain text file

const ResourceContentType('text/plain')
directory → const ResourceContentType

Directory

const ResourceContentType('application/octet-stream')
binary → const ResourceContentType

Binary data

const ResourceContentType('application/octet-stream')
any → const ResourceContentType

Any

const ResourceContentType('*/*')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
String value of the access type
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ResourceContentType>
A constant List of the values in this enum, in order of their declaration.