ResourceMetadata class

Constructors

ResourceMetadata({required int contentLength, required String contentType, required DateTime lastModified, required String eTag, required DateTime? lastAccessed, required String acceptPatch, required String wacAllow})

Properties

acceptPatch → String
final
contentLength → int
final
contentType → String
final
eTag → String
final
hashCode → int
The hash code for this object.
no setterinherited
lastAccessed ↔ DateTime?
getter/setter pair
lastModified → DateTime
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wacAllow → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited