profilePictureFile top-level constant

String const profilePictureFile

Avatar resource. Stored as a turtle file so the same resource can hold either an unencrypted base64-wrapped image (when the user opts to make their profile public) or the encrypted form produced by writePod() (the default for an app using encryption).

Implementation

const String profilePictureFile = 'avatar.ttl';