Permission class
Data model for parsing permission map of recipient into list of permission objects used in permission table.
Constructors
-
Permission({required String recipientWebId, required String recipientName, required RecipientType recipientType, required String recipientTypeDescription, required String toolTip, required String agentType, required List<
String> permList}) -
const
Properties
- agentType → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
permList
→ List<
String> -
final
- recipientName → String
-
final
- recipientType → RecipientType
-
final
- recipientTypeDescription → String
-
final
- recipientWebId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolTip → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited