deleteExternalFile function
Future<void>
deleteExternalFile(
- String fileUrl, {
- ResourceContentType contentType = ResourceContentType.turtleText,
Delete an external file with path fileUrl and the shared key
if the file is encrypted.
Throws an exception if the file does not exist or any error occurs.
Implementation
Future<void> deleteExternalFile(
String fileUrl, {
ResourceContentType contentType = ResourceContentType.turtleText,
}) async {
await deleteResource(fileUrl, contentType);
// await deleteAclForResource(fileUrl);
await KeyManager.removeSharedIndividualKey(fileUrl);
/// av: Need to add the functionality to remove the log line from
/// permission log. Otherwise, it will give an error.
}