readExternalPod function
Read fileUrl from an external POD.
We first check if the user is logged in and then read and parse the file content.
fileUrl - The URL to the external file to read
Implementation
Future<String> readExternalPod(String fileUrl) async =>
await readPod(fileUrl, pathType: PathType.absoluteUrl);